#
# spec file for package scummvm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with faad
%bcond_with mad

Name:           scummvm
Version:        1.8.1
Release:        3.2
Summary:        Interpreter for several adventure games
License:        GPL-2.0+
Group:          Amusements/Games/Other
Url:            http://www.scummvm.org/
Source:         http://www.scummvm.org/frs/scummvm/%{version}/scummvm-%{version}.tar.xz
# PATCH-FEATURE-UPSTREAM https://github.com/scummvm/scummvm/pull/797
Patch0:         appdata.xml.patch
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig(alsa) >= 0.9
BuildRequires:  pkgconfig(flac) >= 1.0.1
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libpng) >= 1.2.8
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(sdl) >= 1.2.2
BuildRequires:  pkgconfig(theoradec) >= 1.0
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(zlib)
%if %{with faad}
BuildRequires:  libfaad-devel
%endif
%if %{with mad}
BuildRequires:  pkgconfig(mad)
%endif
%ifarch %{ix86}
BuildRequires:  nasm
%endif
Suggests:       %{name}-extra
Suggests:       %{name}-tools

%description
ScummVM is an interpreter that will play graphic adventure games written for
LucasArts' SCUMM virtual machine (such as Day of the Tentacle and
Monkey Island), Sierra's AGI adventures (such as early King's Quest and
Space Quest games), Adventure Soft's Simon the Sorcerer 1, 2 and Feeble Files,
Revolution Software's Beneath a Steel Sky and Broken Sword 1, 2 and 2.5,
Interactive Binary Illusions' Flight of the Amazon Queen,
Coktel Vision's Gobliiins, Wyrmkeep's Inherit the Earth, Westwood's
Legend of Kyrandia, and various others.

%package extra
Summary:        Extra engines for ScummVM
Group:          Amusements/Games/Other
Requires:       %{name} = %{version}

%description extra
lastexpress and toltecs engines for ScummVM.
These engines are in a worse state, but allow to play extra games.

%prep
%setup -q
%patch0 -p1
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" base/version.cpp backends/plugins/elf/version.cpp
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" base/version.cpp backends/plugins/elf/version.cpp

%build
# No rpm configure because scummvm's configure isn't a real configure and thus
# doesn't understand some of the options %%configure passes.
CXXFLAGS="%{optflags}" ; export CXXFLAGS ; \
./configure --prefix=%{_prefix} \
            --bindir=%{_bindir} \
            --datarootdir=%{_datadir} \
            --mandir=%{_mandir} \
            --libdir=%{_libdir} \
            --docdir=%{_docdir}/%{name} \
            --enable-verbose-build \
            --enable-plugins \
            --enable-engine-dynamic=lastexpress \
            --enable-engine-dynamic=wintermute
# Subengines are not included even as dynamic since I don't want to touch the main engines
make %{?_smp_mflags}

%install
%make_install

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(0644,root,root,0755)
%attr(0755,-,-) %{_bindir}/scummvm
%{_datadir}/scummvm
%{_mandir}/man6/scummvm.6*
%{_datadir}/applications/scummvm.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/scummvm.appdata.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/pixmaps/scummvm.xpm
%{_docdir}/%{name}

%files extra
%defattr(0644,root,root,0755)
%{_libdir}/scummvm

%changelog
* Wed Aug  3 2016 olaf@aepfle.de
- Correct buildconditionals: aac -> faad, mp3 -> mad
* Fri Jul 29 2016 mailaender@opensuse.org
- Update to 1.8.1 (maintenance release)
  * General:
  - Removed TESTING flag from several supported games.
  - Added Chinese Pinyin translation.
  - Fixed cursor stuttering in the launcher that occured on some systems.
  * BBVS:
  - Fixed game restart.
  * CinE:
  - Fixed sound effect loading.
  * Drascula:
  - Fixed text alignment to be faithful to the original.
  - Fixed character walking off screen.
  - Fixed loading savegames in the Pendulum scene.
  - Fixed wrong background for inventory items during chapter 6 in the
    Spanish version.
  - Fixed animations speed (they were running two times slower than in the
    original engine).
  - Fixed noise at start and/or end of speech. This was most noticeable
    with the Spanish speech.
  - Fixed delay when interacting with the verb menu and the inventory.
  - Fixed possibility to pick up the axe in the castle multiple times.
  * Gob:
  - Fixed lock up for some games during sound initialization.
  * KYRA:
  - Fixed potential crash when using swamp snake potion on the rat in Hand
    of Fate. (NOTE: This fix was included in version 1.8.0, but it was not
    added to the NEWS file).
  - Fixed missing voice reactions when hitting enemies in CD version of
    Lands of Lore.
  * Lab:
  - Fixed lock-up during ending sequence.
  - Improved internal game controls.
  - Fixed lock-up during some in-game animations.
  * SAGA:
  - Fixed user interface colors in the French and German versions of I Have No
    Mouth and I Must Scream.
  * SCI:
  - Make cursor workarounds work properly on OpenPandora (and other devices, that
    support touch screen and analog sticks/mouse at the same time)
  - Script patch to fix broken ending battle in multilingual King's Quest 5
    (French, German + Spanish versions are all broken)
  - Fixed invalid memory access, when loading broken King's Quest 5 credit music track
  - Fixed lowres/hires issues in King's Quest 6 when saving, changing the lowres/hires
    setting and restoring the saved game afterwards.
  * SCUMM:
  - Fixed detection of Maniac Mansion from Day of the Tentacle in the Windows
    version of ScummVM.
  - Fixed a sound effect not stopping in Loom EGA with AdLib.
  * Broken Sword 2.5:
  - Added option to use English speech instead of German one when no speech is
    available for the selected language.
  - Fixed resource releasing on game exit.
  - Fixed game restart after language change in-game.
  - Fixed flickering in main Menu.
  - Fixed long save time on Windows.
- Add appdata.xml.patch
* Sun Mar  6 2016 mailaender@opensuse.org
- Update to 1.8.0
  * New Games:
  - Amazon: Guardians of Eden
  - Beavis and Butthead in Virtual Stupidity
  - Broken Sword 2.5: The Return of the Templars
  - Labyrinth of Time
  - Rex Nebular and the Cosmic Gender Bender
  - Sfinx
  - The Lost Files of Sherlock Holmes: The Case of the Rose Tattoo
  - The Lost Files of Sherlock Holmes: The Case of the Serrated Scalpel
  - Zork: Grand Inquisitor
  - Zork Nemesis: The Forbidden Lands
  * Updated the MT-32 (Miles Audio) emulator
  * Overhauled the graphics subsystem in AGI
- Remove scummvm-underlinking.patch
- Remove scummvm-themed_icons.patch
* Sat Sep 13 2014 mailaender@opensuse.org
- Update to 1.7.0
  * New Games:
  - Added support for Chivalry is Not Dead.
  - Added support for Return to Ringworld.
  - Added support for The Neverhood.
  - Added support for Mortville Manor.
  - Added support for Voyeur.
  * General:
  - Updated Munt MT-32 emulation code to version 1.3.0.
  - Switched from our custom JPEG and PNG decoders to libjpeg(-turbo) and
    libpng, which are faster and can handle more images.
  - Added generic OpenGL (ES) output (based on GSoC Task).
  - The GUI can now be rendered in 32-bits.
  - The build system has been changed to be more modular and easier to add new
    engines.
  * SDL:
  - Added OpenGL graphics mode based on our generic OpenGL output. This
    allows for arbitrary output sizes. However, it does not support special
    filters like AdvMAME, HQ, etc.
  * AGOS:
  - Added mouse wheel support for inventory and save game lists.
  - Enabled verb name display in Simon the Sorcerer 2.
  - Fixed the Feeble Files loyalty rating in the English 4CD version. (This
    was apparently a bug in the original game. It is currently unknown if
    other versions still have the same problem.)
  * Broken Sword 1:
  - Added back support for MPEG-2 videos.
  * Broken Sword 2:
  - Added back support for MPEG-2 videos.
  * CGE:
  - Added an option to enable "Color Blind Mode" to the ScummVM GUI.
  * Gob:
  - Improved video quality in Urban Runner.
  * Hopkins:
  - Added an option to toggle "Gore Mode" from the ScummVM GUI.
  - Fixed bug that could cause the music to stop prematurely.
  * Pegasus:
  - Fixed several rare crashes and glitches.
  - Fixed multiple bugs carried over from the original binary.
  * SCI:
  - Added support for the more detailed RAVE lip syncing data in the Windows
    version of King's Quest 6. Portraits should now be much more expressive
    when talking.
  - Added support for simultaneous speech and subtitles in the CD versions
    of Laura Bow 2 and King's Quest 6 (toggled either in-game with the new
    "Dual" audio state, or via the ScummVM audio options).
  - Fixed music fading.
  - Fixed several script bugs in Camelot, Crazy Nick's, Hoyle 3, QFG1VGA, KQ5,
    KQ6, LB2, LSL2, LSL5, Pharkas, PQ1VGA, SQ4, SQ5.
  - Improved the MIDI parser so that music event processing is done more
    properly.
  * SCUMM:
  - Changed the saved game naming scheme of HE games to always contain
    the target name.
  - Fixed having multiple coaches in Backyard Football.
  - Improved AdLib support for Loom and Indiana Jones and the Last Crusade.
    This makes sound effects like, for example, the typewriter and waterfall
    in Indiana Jones and the Last Crusade sound like in the original.
  - Added support for the Steam versions of Indiana Jones and the Last
    Crusade, Indiana Jones and the Fate of Atlantis, Loom and The Dig. Both
    the Windows and the Macintosh versions are supported.
  * TONY:
  - Savegames in Tony Tough now work on big-endian systems.
  * Tinsel:
  - Discworld 1 and 2 no longer crash on big-endian systems.
* Thu Jun  6 2013 reddwarf@opensuse.org
- Update to 1.6.0
  * New Games:
  - Added support for 3 Skulls of the Toltecs.
  - Added support for Eye of the Beholder.
  - Added support for Eye of the Beholder II: The Legend of Darkmoon.
  - Added support for Hopkins FBI.
  - Added support for Tony Tough and the Night of Roasted Moths.
  - Added support for The Journeyman Project: Pegasus Prime.
  - Added support for the Macintosh version of Discworld 1.
  * General:
  - Added a new save/load chooser based on a grid of thumbnails. This is only
    supported for resolutions bigger than 640x400. The old chooser is still
    available and used for games without thumbnail support. It is possible to
    select the old one as default too.
  - Rewrote VideoDecoder subsystem.
  - Added Galician translation.
  - Added Finnish translation.
  - Added Belarusian translation.
  - Using the mouse wheel on a slider widget now changes the value by the
    smallest possible amount. This is more predictable than the old behaviour,
    which was to change the value by "one pixel" which would sometimes not
    change it at all.
  - Updated MT-32 emulation code to latest munt project snapshot.
  - Added FluidSynth settings dialog, mainly for reverb and chorus settings.
  - Fixed crash on certain Smacker movies.
  * Cine:
  - Improved audio support for Amiga and AtariST versions of Future Wars.
    Now music fades out slowly instead of stopping immediately. Sound
    effects are now properly panned, when requested by the game.
  * CGE:
  - Soltys contains a puzzle requiring the ALT key to be pressed while clicking
    on an object. This puzzle has been disabled on devices not using this key.
  * Drascula:
  - Resolved multiple UI issues with the original save/load screen.
  - Added advanced savegame functionality, including savegame timestamps and
    thumbnails and the ability to load and delete savegames from the launcher.
    It's now possible to use the ScummvM save/load dialogs.
  - The F7 key (previously unmapped) now always shows the ScummVM load screen.
    The F10 key displays either the original save/load screen, or the ScummVM
    save screen, if the user has selected to use the ScummVM save/load
    dialogs.
  * Dreamweb:
  - Now that the game is freeware, there is a small extra help text showing
    the available commands in the in-game terminals when the player uses the
    'help' command. Previously, players needed to consult the manual for the
    available commands. Since this reference to the manual is a form of copy
    protection, this extra line can be toggled by the ScummVM copy protection
    command line option.
  * Groovie:
  - Simplified the movie speed options, and added a custom option for The 7th
    Guest. Movie options are now "normal" and "fast", with the latter changing
    the movie speed in T7G to match the faster movie speed of the iOS version.
    The game entry might need to be readded in the launcher for the new setting
    to appear.
  * SAGA:
  - Added music support for the Macintosh version of I Have No Mouth and, I
    Must Scream.
  * SCUMM:
  - Implemented Monkey Island 2 Macintosh's audio driver. Now we properly
    support its sample based audio output. The same output is also used for
    the m68k Macintosh version of Indiana Jones and the Fate of Atlantis.
  - Improved music support for the Macintosh version of Monkey Island 1. It
    now uses the original instruments, rather than approximating them with
    General MIDI instruments, and should sound a lot closer to the original.
  - Added sound and music support for the Macintosh version of Loom.
  - Handle double-clicking in the Macintosh version of Loom.
  - Major bugfixes in INSANE (the Full Throttle bike fights).
  * TOUCHE:
  - Added support for Enhanced Music by James Woodcock
    (http://www.jameswoodcock.co.uk/category/scummvm-music-enhancement-project/).
- Remove scummvm-nostrip.patch
- Add scummvm-themed_icons.patch
* Tue Oct 23 2012 cfarrell@suse.com
- license update: GPL-2.0+
  SPDX format - plus it appears as though only one license relevant binary
  is created (2 if you count the extra package) - meaning that the binary
  is almost GPL licensed (i.e. there does not appear to be a library which
  could be LGPL licensed)
* Sat Jul 21 2012 reddwarf@opensuse.org
- Update to 1.5.0
  * New Games:
  - Added support for Backyard Baseball 2003.
  - Added support for Blue Force.
  - Added support for Darby the Dragon.
  - Added support for Dreamweb.
  - Added support for Geisha.
  - Added support for Gregory and the Hot Air Balloon.
  - Added support for Magic Tales: Liam Finds a Story.
  - Added support for Once Upon A Time: Little Red Riding Hood
  - Added support for Sleeping Cub's Test of Courage.
  - Added support for Soltys.
  - Added support for The Princess and the Crab.
  * General:
  - Updated MT-32 emulation code to latest munt project snapshot.
    The emulation improved dramatically.
  - Implemented support for TrueType fonts via FreeType2 in our
    GUI. Along with it GNU FreeFont was also added to our modern
    theme. Note that not all ports take advantage of this.
  - Added Basque translation.
  - Added custom game and engine options in the AGI, DREAMWEB,
    KYRA, QUEEN, SKY and SCI engines. It is now possible to
    toggle these options via the Engine tab when adding or
    editing a configuration for a game. In most cases, you will
    have to run each game once or readd them all in ScummVM's
    launcher in order to get the custom options tab.
  - Improved predictive dialog look.
  - Various GUI improvements.
  * Broken Sword 1:
  - Fixed incorrect sound effects in the DOS/Windows demo.
  - Added support for PlayStation videos.
  - Fixed missing subtitles in the demo.
  * Broken Sword 2:
  - Added support for PlayStation videos.
  * Cine:
  - Implemented Roland MT-32 output driver.
  * Drascula:
  - Added Spanish subtitles in the Von Braun cutscene (#3069981:
    no subtitles in scene with "von Braun").
  * Gob:
  - Fixed a crash in Lost in Time
  - Rewrote the AdLib player. Enabled the now working MDY player
    in Fascination and Geisha.
  * SCUMM:
  - Added support for the Macintosh version of SPY Fox in Hold
    the Mustard.
  - Added a difficulty selection dialog for Loom FM-TOWNS.
  - Fixed graphical glitches in HE98 version of Pajama Sam's Lost
    & Found.
* Wed May 16 2012 reddwarf@opensuse.org
- fix license issues (bnc#761623)
* Fri Mar 30 2012 reddwarf@opensuse.org
- update to 1.4.1
* Thu Sep  1 2011 reddwarf@opensuse.org
- update to new 1.3.1 release
  * General:
  - Improved audio device detection and fallback.
    There should be no more silent errors due to invalid audio devices.
    Instead ScummVM should pick up a suitable alternative device.
  * Mohawk:
  - Added detection entries for more variants of some Living Books
    games.
  * Tinsel:
  - Fixed a regression that made Discworld uncompletable.
  * SAGA:
  - Fixed a regression in Inherit the Earth's dragon walk code which
    was causing crashes there.
  - Fixed a regression causing various crashes in I Have No Mouth and
    I Must Scream.
  * SCI:
  - Added detection entries for some Macintosh game versions.
  - Audio settings are now stored correctly for the CD version of EcoQuest 1.
  * SCUMM:
  - Fixed graphics bug in FM-TOWNS versions of games on ARM devices
    (Android, iPhone, etc.).
* Thu Jun  2 2011 cmorve69@yahoo.es
- update to new 1.3.0 release
  * New Games:
  - Added support for Backyard Baseball.
  - Added support for Backyard Baseball 2001.
  - Added support for Urban Runner.
  - Added support for Playtoons: Bambou le Sauveur de la Jungle.
  - Added support for Toonstruck.
  - Added support for Living Books v1 and v2 games.
  - Added support for Hugo's House of Horrors, Hugo 2: Whodunit?
    and Hugo 3: Jungle of Doom.
  - Added support for Amiga SCI games (except Conquests of the
    Longbow).
  - Added support for Macintosh SCI1 games.
  * General
  - Added Danish translation.
  - Added Norwegian Bokmaal translation.
  - Added Norwegian Nynorsk translation.
  - Added Swedish translation.
  - Added Debug Console to Cine, Draci, Gob, MADE, Sword1, Touche
    and Tucker Engines.
  - Closed significant memory leaks. RTL should now be more
    usable.
  * AGOS:
  - Closed memory leaks in Simon 2 and Feeble Files.
  * Cine:
  - Corrected memory leaks and invalid memory accesses.
    Future Wars should be more stable.
  - Made Operation Stealth completable, though significant
    graphical glitches remain so not official supported.
  * Drascula:
  - Added German and French subtitles in the Von Braun cutscene
    (#3069981: no subtitles in scene with "von Braun").
  - Improved French translation of the game.
  - Added support for "Return To Launcher".
  * Gob:
  - Fixed "Goblin Stuck On Reload" bugs affecting Gobliiins.
  * Kyra:
  - Closed memory leaks.
  * Parallaction:
  - Corrected issue which could cause crash at engine exit.
  - Closed memory leaks in Nippon Safes Amiga.
  * SCI:
  - Added a CMS music driver for SCI1 - SCI1.1 games.
  - Added an option to toggle undithering from the ScummVM GUI.
  - Added several previously missing parts of the game state in
    saved games, such as game played time, script created
    windows, the script string heap and information related to
    the text parser in old EGA games.
  - Added support for SCI1.1 magnifier cursors.
  - Added support for the keypad +/- keys.
  - Added support for the alternative General MIDI tracks in the
    Windows CD versions of Eco Quest, Jones in the Fast Lane,
    King's Quest 5 and Space Quest 4.
  - Added support for the alternative Windows cursors in the
    Windows versio of King's Quest 6.
  - Added support for simultaneous speech and subtitles in the CD
    versions of Space Quest 4 and Freddy Pharkas.
  - Corrected resource loading leaks.
  - Corrected several problems and issues in the Skate-O-Rama
    rooms in Space Quest 4.
  - Corrected several issues in Hoyle Classic Card Games.
  - Fixed several graphical glitches (like, for example, parts of
    the screen that weren't erased correctly under some rare
    circumstances).
  - Fixed several script bugs.
  - Fixed several pathfinding related issues and lockups (like,
    for example, a lockup in the shower scene of Laura bow 1 and
    pathfinding in some screens during the chase sequence in
    Laura Bow 2).
  - Fixed several music related glitches and possible lockups
    (like, for example, a rare music lockup that occurred when
    loading a saved game outside the palace in Quest for Glory 3).
  - Fixed possible problems and lockups in the character import
    screens of Quest for Glory 2 and 3.
  - Fixed a bug that caused a lockup in the SCI1 CD version of
    Mixed Up Mother Goose, after Tommy Tucker's song.
  - Fixed a script bug in the CD version of King's Quest 5, which
    caused a lockup under certain circumstances when going
    outside the witch's house in the dark forest.
  - Function keys now work correctly when the num lock key is on.
  - Improved support for fanmade game scripts.
  - Improved support for non-English versions of games.
  - Made several enhancements and fixes related to MT-32 music
    (e.g. reverb).
  - Music is no longer out of tune when loading saved games.
  * SCUMM:
  - Improved support for FM-TOWNS versions of games.
  * Teenagent:
  - Closed memory leaks.
  * Tinsel:
  - Closed memory leaks in Coroutines.
  - Added enhanced music support for the German CD
    "Neon Edition" re-release of Discworld 1.
  * Touche:
  - Corrected memory leaks and minor issues.
  * Tucker:
  - Added workarounds for several issues present in the original game.
  * SDL ports:
  - Closed memory leaks in Mouse Surfaces.
* Sun Dec 12 2010 reddwarf@opensuse.org
- update to new 1.2.1 release
  * General
  - Add Hungarian translation.
  - Add Brazilian Portuguese translation.
  * Cruise:
  - Fixed a problem with Raoul appearing when examining the Book
  * Groovie:
  - Fixed a regression that made the Russian version of T7G crash.
  * Lure:
  - Fixed several NPC movement bugs
* Mon Oct 11 2010 reddwarf@opensuse.org
- update to new 1.2.0 release
* Thu May  6 2010 cmorve69@yahoo.es
- update to new 1.1.1 release
* Mon Apr  5 2010 cmorve69@yahoo.es
- update to new 1.1.0 release
* Thu Oct 22 2009 cmorve69@yahoo.es
- make it compile in openSUSE 11.2
* Mon May  4 2009 cmorve69@yahoo.es
- made mpeg2 and mp3 support optional
- updated to new 0.13.1 release
  * AGOS:
  - Fixed crash after OmniTV video is played in The Feeble Files
  - Fixed crashes when exploring Jack the Ripper scene in the PC version of
    the Waxworks
  - Fixed palette glitches in the AtariST version of Elvira 2
  - Fixed noise that can occur when sound effects are played, when exploring
    Pyramid scene in the Waxworks
  * Gob:
  - Fixed a crash in the Italian version of Woodruff
  * Groovie:
  - Fixed some issues with music in The 7th Guest
  * Parallaction:
  - Fixed the sarcophagus puzzle in Nippon Safes
  * SAGA:
  - Fixed a crash in Inherit the Earth
  - Fixed glitches in the save/load dialog.
  * Sword2:
  - Fixed random sound corruption when using the original sound files.
  * Game launcher:
  - Fixed a case where memory could be corrupted
  - Fixed the small cursor in the modern theme
  - Fixed a bug in the theme engine, which could cause crashes
  - Made the file browser bigger in 1x mode
* Fri Mar  6 2009 cmorve69@yahoo.es
- fixed lincense tag
- removed README.SUSE file
- package scummvm-tools in a separate package
- updated description
- various fixes taken from Fedora and upstream spec files
- updated to new 0.13.0 release
  * General:
  - Added MIDI driver for Atari ST / FreeMint.
  - Added a 'Load' button to the Launcher (not supported by all engines).
  - Added a new global main menu (GMM) dialog usable from all engines.
  - Added the ability to return to the launcher from running games (via the
    GMM).
  - Rewrote GUI renderer to use an vector based approach.
  - Rewrote GUI configuration to use XML.
  * New Games:
  - Added support for Blue's 123 Time Activities.
  - Added support for Blue's ABC Time Activities.
  - Added support for Bud Tucker in Double Trouble.
  - Added support for The 7th Guest.
  * KYRA:
  - Added support for Auto-save feature.
  - Added support for MIDI music.
  * SCUMM:
  - Implemented radio-chatter effect in The DIG.
* Mon Sep  1 2008 sndirsch@suse.de
- updated to new 0.12.0 release
  * New Games:
  - The Legend of Kyrandia: Book Two: Hand of Fate.
  - The Legend of Kyrandia: Book Three: Malcolm's Revenge.
  - Lost in Time.
  - The Bizarre Adventures of Woodruff and the Schnibble.
  - PC version of Waxworks.
  - Macintosh version of I Have no Mouth, and I must Scream.
  - Drascula: The Vampire Strikes Back.
  * General
  - Added CAMD MIDI driver for AmigaOS4.
  - Revived the PS2 port (was already in 0.11.1 but was
    forgotten in the release notes).
  - Plugged numerous memory leaks in all engines (part of
    GSoC'08 task),
  - Added audio double buffering to the SDL backend, which
    fixes the problems with the MT-32 emulator on Mac OS X
    (for now only enabled on Mac OS X).
  * AGOS:
  - Fixed crashes during certain music in Amiga versions of
    Elvira 1 and Simon the Sorcerer 1.
  - Fixed palette issues in Amiga versions of Simon the
    Sorcerer 1.
  * Queen:
  - Speech is played at the correct sample rate. (It used to be
    pitched a bit too low.)
  * SCUMM:
  - Rewrote parts of Digital iMUSE, fixing some bugs.
  - Rewrote the internal timer code, fixing some speed issues
    in e.g. COMI.
  - Improved support for sound effects in Amiga version of Zak
    McKracken.
  - Added support for mixed Adlib/MIDI mode in Monkey Island 1
    (Floppy).
* Fri Feb 29 2008 sndirsch@suse.de
- updated to new 0.11.1 release
  * fixed digital iMUSE system (better COMI experience)
  * squashed King's Quest 4 bugs
  * improved support for fanmade AGI games
  * fixed several crashes and lock-ups in Lure of the Temptress,
    Inherit the Earth and I Have no Mouth
* Sat Jan 12 2008 sndirsch@suse.de
- updated to new 0.11.0 release
  * New Games:
  - Added support for Elvira: Mistress of the Dark.
  - Added support for Elvira 2: The Jaws of Cerberus.
  - Added support for I Have no Mouth, and I Must Scream (demo
    and full game).
  - Added support for preAGI game Mickey's Space Adventure.
  - Added support for preAGI game Troll's Tale.
  - Added support for preAGI game Winnie the Pooh in the Hundred
    Acre Wood.
  - Added support for Amiga version of Waxworks.
  - Added support for Lure of the Temptress.
  * New Ports:
  - Added iPhone port.
  - Added Maemo port for Nokia Internet tablets.
  * General:
  - Added ARM assembly routines for code in the sound mixer and
    SCUMM video playback, resulting in some nice speedups on
    several ports.
  - Improved the way keyboard input is handled internally,
    resolving some odd quirks in some game / port combinations.
  - Added optional 'confirm exit' dialog to the SDL backend.
  - Added support for TiMidity++ MIDI server.
  - Added DMedia MIDI driver for IRIX.
  - Improved detection of new game variants and localized
    versions.
  - Completely reworked internal access to files. (GSoC Task)
  - Added option to delete games from the list with Del key.
  - Added support for "~/" prefix being substituted by $HOME in
    paths
    on POSIX systems (Linux, Mac OS X etc.).
  * AGI:
  - Added support for AGI256 and AGI256-2 hacks (GSoC Task)
  - Added support for Amiga menus and palettes (GSoC Task)
  - Better support for early Sierra AGI titles
  * AGOS:
  - Fixed crashes related to OmniTV playback in The Feeble Files.
  - Improved work on 64-bit systems.
  * Broken Sword 1:
  - Added support for FLAC encoded music.
  * Kyrandia:
  - Added support for Macintosh version.
  * Parallaction:
  - Added support for Amiga version of Nippon Safes, Inc.
  - Many bugfixes
  * Queen:
  - Added support for Adlib music.
  - Added missing music patterns playback in Amiga version.
  * SCUMM:
  - Added subtitle skipping (via '.' key) in older games which
    didn't have this feature so far (e.g. Zak, MM, Indy3, Loom).
  - Added support for Chinese COMI.
  - Better support for eastern versions of games.
  - Various fixes for COMI and other games.
  - Added support for original save menus (browse only). Use
    Alt-F5 to activate.
  - Added support for Spanish version of NES Maniac Mansion.
  - Better support for German version of C64 Maniac Mansion.
  - Fixed bug with cursors in Windows versions of Humongous
    Entertainment games.
  * SAGA:
  - Added support for compressed sound effects, voices and music.
  * Touche:
  - Added workarounds for some glitches/issues present in the
    original game.
  * WinCE Port:
  - Switched compilers again. Now using cegcc
    (http://cegcc.sourceforge.net/).
  - Plugins now supported for WinCE (but not used in this
    release).
  - Redesigned 'Free Look' action, mainly for the lure engine's
    requirements.
  - Smaller optimization setting to counteract the growth of the
    executable.
  - Various bug fixes.
  * GP2X Port:
  - Support F200 Touchscreen
  - Various fixes to input code
* Fri Nov 30 2007 sndirsch@suse.de
- fixed gcc version check
* Sun Nov 18 2007 mkoenig@suse.de
- fix build
* Wed Jun 20 2007 sndirsch@suse.de
- updated to new 0.10.0 release
  * Several new engines and thus new games supported:
  - Sierra AGI engine: Space Quest I & II, King's Quest I-III
    and many more, including a vast number of fan-made games
  - Cinematique evo 1 engine: Future Wars
  - GOB engine: Bargon Attack, Gobliins 2, Goblins 3, Ween: The
    Prophecy
  - AGOS engine: Simon the Sorcerer's Puzzle Pack
  - Parallaction engine: Nippon Safes Inc.
  - Touche: The Adventures of the Fifth Musketeer engine.
  * DXA movies (higher quality than MPEG2) can be compressed
    better now and can be used for the Broken Sword cutscenes.
  * Added 'Mass Add' feature to the Launcher, which allows you to
    scan for all games in all subdirectories of a given directory
    (to use it, press shift then click on "Add Game").
  * Many nice improvements to our ports.
  * And as usual a gazillion small fixes, tweaks and improvements.
* Tue May  1 2007 sndirsch@suse.de
- added Provides/Obsoletes for sarien since Sarien project stopped
  its development, continuing the development into ScummVM's AGI
  engine
* Thu Jan  4 2007 sndirsch@suse.de
- added 'modern' GUI theme
* Tue Oct 24 2006 sndirsch@suse.de
- updated to new 0.9.1 release
  * fixes Kyra bug which made game uncompletable
* Sun Oct 22 2006 sndirsch@suse.de
- updated to release 0.9.1 (2006-10-29)
  * New Ports:
  - Added Nintendo DS port.
  - Added GP2X port.
  - Added GP32 port.
  * General:
  - Fixed potential garbage and/or crash in debug console.
  - Removed restriction on 27 games per game id when added via
    launcher.
  * SCUMM:
  - Improved support for international versions of HE games.
  - Fixed rare actor drawing glitches.
  - Fixed path finding during smart star challendge in Big
    Thinkers 1st Grade,
  - Fixed graphical glitches in stomach location of Pajama Sam 3.
  - Fixed graphical glitches in HE80 version of Putt-Putt Travels
    Through Time.
  - Fixed FM-TOWNS version of Indy3 failing on Amiga port.
  - Fixed crash in MM NES when clicking on top screen area
  - Now it is possible to turn on or off subtitles during SMUSH
    movies
  * Simon:
  - Improved support for international versions of the Feeble
    Files.
  - Fixed undefined behaviour when loading music.
  - Fixed crash when displaying some subtitles in the Feeble
    Files.
  - Fixed crackling sound in Mac version of Feeble Files
  * BASS:
  - Fixed character spacing in LINC terminals in floppy version
    v0.0303
  - Fixed a regression which caused incorrect adlib music
    emulation
  * Broken Sword 1:
  - Fixed speech-related crashes.
  * Broken Sword 2:
  - More robust handling of the optional startup.inf file.
  * Kyrandia:
  - Scrolling in the Kyrandia intro is less CPU intensive, at the
    cost of not being as smooth as before.
  - Fixed a tiny graphics glitch in the Kyrandia intro.
  - Improved screen update handling, speeds up drawing on small
    devices.
  - Improved resource loading, faster startup.
  * PSP Port:
  - Fixed crashes during scrolling scenes in certain SCUMM games.
  - Added saving of thumbnail in SCUMM savegames.
  * PS2 Port:
  - Overlay uses higher resolution now.
  - Can boot from USB, HDD etc. as well.
  * WinCE Port:
  - Several bugfixes
  - Re-add support for 2002 based devices
* Tue Oct 17 2006 sndirsch@suse.de
- scummvm-template-fix.diff:
  * fixes compilation errors with new gcc
* Wed Jun 21 2006 sndirsch@suse.de
- updated to release 0.9.0:
  New Games:
  - Added kyra engine (for the Kyrandia series). Currently only
    the first part of the series is supported.
  - Added support for The Feeble Files
  General:
  - Switched from CVS to Subversion.
  - Restructured our source tree partially.
  - Fixed a bug that prevented you from overriding the scaler from
    the command line for 640x480 games.
  - Added subtitle configuration controls to the Launcher options
    dialogs.
  - GUI was completely redesigned and is now themeable.
  SCUMM:
  - Rewrote the detection code, for improved accuracy and better
    support of fan translations. It should now work much better
    on games with unknown MD5.
  - Added subtitle configuration controls to the options dialog.
  - Fixed graphical glitches in several HE games.
  - Fixed palette glitches in Big Thinkers 1st Grade.
  - Fixed songs in the kitchen of Pajama Sam 1.
  SAGA
  - Fixed sound distortion in the Inherit the Earth demo.
  Simon
  - Improved Hebrew support
  - Lots of long-overdue cleanups and re-structuring were made to
    accomodate for The Feeble Files.
  - Fixed a rare MIDI bug that would cause a channel to change
    volume without adjusting it to the master volume.
  - Fixed delay after introduction of Simon the Sorcerer 1 demo
    (With speech)
  - Fixed music tempo in DOS versions of Simon the Sorcerer 1.
  Broken Sword 1:
  - Added support for the --save-slot option.
  Broken Sword 2:
  - Major rewrite of how game resources are accessed in memory.
    This should fix alignment issues reported on some platforms.
  - Missing data files are handled more gracefully.
  WinCE Port:
  - Added: PocketPC: Vertical oversampling scaler 320x200=>320x240
    when panel not shown (n0p)
  - Added: PocketPC: Right click by double-tapping (n0p)
  - Fixed: All: Clipping issues in some cases
  - Added: PocketPC: Mouse emulation using keys
  - Added: Smartphones: Virtual keyboard popup
  - Fixed: Smartphones: Incorrect screen blit in SDL port
  - Added: All: Mouse cursor visible on panel if using emulated
    mouse
  - Added: All: Inverse landscape mode
  - Fixed: PocketPC: Dialogs cut-off/not redrawn
* Tue Jun 13 2006 dmueller@suse.de
- build parallel
* Sat Jun 10 2006 sndirsch@suse.de
- updated to current CVS (2006-06-11)
  * various fixes
* Mon May 29 2006 sndirsch@suse.de
- updated to current CVS (2006-05-30)
  * obsoletes gob2.diff
  * heavy development in gob2 engine
* Sat May 27 2006 sndirsch@suse.de
- updated to current CVS (2006-05-28)
  * adds eperimental support for lure, cine, agi *and* gob2 (at
    least the intro works now including sound)
* Sun Feb  5 2006 sndirsch@suse.de
- updated to release 0.8.2 (2006-02-08)
  * General:
  - Fixed OS X bundle building when using GCC 3.3.
  * SCUMM:
  - Added support for rotating/scaling of sprites in HE games.
  * Sword2:
  - Fixed last-minute crash when playing sound effects.
  * WinCE Port:
  - Should fix weird crashes with DOTT stamp and in FOA
  - Fixed Monkey Island blocking keyboard panel on Smartphones
  - Fixed QVGA Smartphone detection
  - Fixed Smartphone double right click issue.
* Sat Jan 28 2006 sndirsch@suse.de
- updated to release 0.8.1
  * General:
  - More descriptive game titles in all engines.
  - Fixed crash when trying to apply aspect-ratio correction to
    games that cannot use it.
  - Fixed potential security vulnerability with oversized PATH
    environment variables.
  - Lowered the default gain for the FluidSynth music driver and
    made it configurable.
  * SCUMM:
  - Scrolling fixes in COMI, so it is less CPU-hungry.
  - Added support for Maniac Mansion NES German version.
  - Fixed mouse button states in COMI.
  - Fixed overflow when using control panel for robot in the Dig.
  - Added support for sound code, used by songs in HE games.
  - Improved shadows in later HE games.
  - Fixed subtitles glitches in HE games.
  - Improved music/sound for HE games.
  - Improved support for international versions of HE games.
  - Improved support for Macintosh versions of games.
  - Fixed several minor bugs.
  * BASS:
  - Fix crash when speed/volume sliders are clicked and then
    dragged out of the scummvm window.
  * Gob:
  - Fixed disappearing cursor when level password is typed in
  - Warn user if he tries to run CD version directly from CD under
    Windows
  * Queen:
  - Fixed charset for Spanish version.
  * SAGA:
  - Fixed digital music playback under BE systems.
  * Simon:
  - Implemented more precise MD5-based game detection.
  - Added Polish support for Simon the Sorcerer 2.
  - Fixed fades during ride to goblins camp in Simon the Sorcerer 2.
  - Fixed palette delay at the end of Simon the Sorcerer 1.
  - Fixed sound looping in Windows version of Simon the Sorcerer 2.
  * Sword1:
  - Fixed a bug where looping sounds would keep playing during
    cutscenes or when displaying any form of control panel dialog.
  - The save game dialog would erroneously claim an I/O error
    occurred if the savegame list had unused slots, and savegames
    were compressed.
  - Fixed a scrolling bug which caused the finale sequence to be
    displayed
    incorrectly.
  * Sword2:
  - Fixes and cleanups to the end credits. The German credits work
    now.
  - Fixed missing speech/music in the second half of the game,
    reported to happen in some versions of the game.
  * PS2 Port:
  - Completely reworked and now really goes official.
  * PSP Port:
  - Fixed a bug that caused Broken Sword 1, and games that use
    ripped CDDA tracks (most notably the CD version of Monkey
    Island 1), to stop functioning properly after a while.
  * WinCE Port:
  - Check backends/wince/README-WinCE for the latest news
  - Fixed disappearing panel when opening a list widget in GUI
  - Knakos patches (QVGA smartphones fix, easier key binding and
    panel switching)
- update scummvm tools to current CVS sources (2006-01-29)
* Tue Jan 24 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Mon Jan  9 2006 sndirsch@suse.de
- update scummvm tools to current CVS sources (Bug #141852)
* Thu Nov 24 2005 sndirsch@suse.de
- added -fno-strict-aliasing to fix build
* Fri Oct 28 2005 sndirsch@suse.de
- updated to release 0.8.0
  * New Games:
  - Added SAGA engine (for the games "I Have No Mouth and I Must
    Scream" and "Inherit the Earth").
  - Added Gob engine (for the Goblins series). Currently, only
    the first of the Goblins games is supported.
  * SCUMM engine:
  - Added thumbnail support for savegames.
* Thu Oct 27 2005 sndirsch@suse.de
- updated to daily snapshot (20051027)
* Sun Oct 16 2005 sndirsch@suse.de
- updated to daily snapshot (20051017)
* Fri Oct 14 2005 sndirsch@suse.de
- updated to daily snapshot (20051015)
* Fri Oct  7 2005 sndirsch@suse.de
- updated to daily snapshot (20051008)
* Mon Sep 19 2005 sndirsch@suse.de
- updated to daily snapshot (20050920)
* Sun Sep 11 2005 sndirsch@suse.de
- another update of README.SUSE; now I know the filesize of the
  unconverted version to download (#116335)
* Sat Sep 10 2005 sndirsch@suse.de
- added README.SUSE (#116335)
* Tue Aug  9 2005 sndirsch@suse.de
- added scummvm tools (Bug #103725)
* Sat Jul 30 2005 sndirsch@suse.de
- updated to daily snapshot (20050730)
* Mon Jul 18 2005 sndirsch@suse.de
- updated to daily snapshot (20050718)
- removed obsolete gcc4 patches
* Sun Jul 10 2005 sndirsch@suse.de
- updated to daily snapshot (20050710)
* Sun Jul  3 2005 sndirsch@suse.de
- enabled fluidsynth MIDI driver
- added the build of "The Legend of Kyrandia" engine
- use RPM_OPT_FLAGS everywhere
- use install target
* Thu Jun 23 2005 sndirsch@suse.de
- updated to daily snapshot (20050626)
* Sat Jun 11 2005 sndirsch@suse.de
- updated to daily snapshot (20050612)
* Sat Jun  4 2005 sndirsch@suse.de
- updated to daily snapshot (20050604)
- adjusted gcc4.diff/gcc4-friends.patch
* Sun May 22 2005 sndirsch@suse.de
- gcc4-friends.patch
  * fixes new gcc build error:
  "ISO C++ forbids declaration of 'Win32ResExtractor' with no type"
* Mon May  9 2005 ro@suse.de
- use -mmmx and -msse on x86
* Mon Apr  4 2005 sndirsch@suse.de
- fixed to build with gcc4
* Mon Mar 28 2005 sndirsch@suse.de
- update to 0.7.1:
  * General:
  - Added a MT-32 emulator. (It was actually added in 0.7.0 but
    we forgot to put it into the NEWS file :-).
  - Less memory-hungry MPEG movie playback for the Broken Sword
    games.
  * SCUMM:
  - Fixed wrong actor animation in Full Throttle INSANE
  * Windows Mobile port (PocketPC / Smartphone) :
  - Fixed FOTAQ crash on all platforms when leaving the hotel
    AGAIN
  - Better low quality Adlib emulation for FOTAQ
  - Fix randomly broken Hide Toolbar option (thanks iKi)
  - Fix first hardware key mapping (was not displayed before)
  - Fix BASS & Simon hangs on Smartphone when using the Skip
    hotkey
  - Fix Zone key action on Smartphone (now mapped on key 9)
  - Experimental third party VGA mode (SE-VGA) fix
  - Add Key Mapping option in the launcher (Options/Misc/ Keys)
  - Remove AYGSHELL.DLL dependency to work on CE .Net platforms
  - Fix key mapping issues introduced in 0.7.0
  - Full Throttle interactive action sequences should be more
    playable.
  - New key mapping option "FT Cheat" to win a Full Throttle
    action sequence
  - Quit Simon game with 'Action key' on Smartphones
  * Sword2:
  - Fixed crash caused by attempting to play music from CD1 and
    CD2 at the same time.
  - Fixed crash in the cutscene player if the speech file was
    missing.
  * BASS:
  - Fixed crash when talking to the gardener using spanish text
    with the floppy version.
* Tue Mar 22 2005 sndirsch@suse.de
- removed mad support (usually not required)
* Sat Jan  1 2005 sndirsch@suse.de
- update to 0.7.0:
  * Added preliminary support for 26 Humongous Entertainment titles
  * Added support for FLAC (lossless) encoded audio files
  * Added native support for Macintosh versions of some SCUMM games;
    this means the 'rescumm' tool is now mostly obsolete, and you
    can now play those games directly from the original CD
  * Added smooth horizontal scrolling for The Dig, Full Throttle
    and COMI (matching the original engine)
  * Added support for compressed speech and music in Broken Sword 1
    and Broken Sword 2
  * And as usual, we fixed lots and lots of bugs
- added flac/flac-devel to #neededforbuild -> enabled flac support
* Thu Nov 11 2004 sndirsch@suse.de
- added MPEG-2 support; required for cutscenes of Broken Sword 1/2
  (Bug #48180)
* Thu Aug  5 2004 uli@suse.de
- update -> 0.6.1b (now 64-bit clean, mostly sound-related bugfixes)
* Mon Mar 15 2004 sndirsch@suse.de
- Update to 0.6.0:
  * many bugfixes in all supported game engines
  * dramatic fixes and improvements in the area of sound and music
  * greatly improved game management/options screen
  * two new graphics modes (HQ2x and HQ3x)
  * new support for the following games
  - Maniac Mansion, Zak McKracken, Full Throttle
  - Broken Sword 1 and Broken Sword 2
  - Flight of the Amazon Queen (released now as freeware
    including permission to include it on a Linux distribution!)
* Mon Dec  1 2003 sndirsch@suse.de
- fixed build for ALSA 1.0
* Tue Oct 14 2003 mmj@suse.de
- Don't build as root
- Don't strip explicitly
* Mon Sep 22 2003 uli@suse.de
- no ALSA on s390*
* Fri Aug 15 2003 sndirsch@suse.de
- enabled MIDI support via ALSA sequencer
* Tue Aug 12 2003 sndirsch@suse.de
- Update to 0.5.1 including:
  * Beneath a Steel Sky savegame code completely rewritten,
    eliminating several situations where ScummVM 0.5.0 would
    produce unusable 'frozen' saved games
  * Several other Beneath a Steel Sky bugs have been fixed
  * Some Curse of Monkey Island actor graphical issues have
    been fixed
  * Some issues when running ScummVM fullscreen under MacOS X
    have been resolved
  * MorphOS port has undergone several critical bugfixes
  * Dreamcast port now supports Simon the Sorcerer 1 and 2
* Sat Aug  2 2003 sndirsch@suse.de
- Update to 0.5.0 including:
  * Enhanced versions of Maniac Mansion and Zak McKracken are now
  supported and completable
  * Beneath A Steel Sky is now supported and completable
  * Added support for Amiga version of Monkey Island 1
  * Initial unplayable support for V1 version of Maniac Mansion/Zak
  McKracken
  * Curse of Monkey Island (COMI) support for playing from CD improved
  on Mac OS X
  * Loading COMI savegames for disk 2 doesn't anymore require disk 1
  first
  * Rewritten iMUSE enginee, and many Music fixes (exp. Monkey Island 2)
  * Support for music in Humongous games and simon2dos/simon2talkie
  (XMIDI format)
  * Support for music in simon1demo (Proprietary format)
  * Complete music support for Simon the Sorcerer 2
  * Improved music and sound support in Zak256
  * Added Aspect Ratio option
  * Many other bug fixes, improvements and optimisations
  * Added AdvMame3x filter
  * Fixed crash in Curse of Monkey Island (and possibly other games as
  well)
  * Fixed airport doors in Zak256
  * Fixed crash in SDL backend
  * Fixed various iMUSE bugs
* Mon May 12 2003 mmj@suse.de
- Update to 0.4.0 including:
  * Curse of Monkey Island (comi) support (experimental)
  * Added support for the EGA versions of Loom, Monkey Island and
  Indy3
  * Improved music support in Indy3 and the floppy versions of
  Monkey Island
  * Many Simon the Sorcerer 1 & 2 improvements and fixes
  * Even more pre-alpha support for enhanced versions of V2 SCUMM
  games (Maniac Mansion and Zak)
  * Preliminary support for early Humongous Entertainment titles
  (very experimental)
  * New debug console and several GUI/Launcher enhancements
  * New Save/Load code (easier to expand while retaining
  compatibility)
  * Dreamcast port now works with new games added for 0.3.0b
  * New official PalmOS port
  * Various minor and not so minor SCUMM game fixes
  * Large memory leak fixed for The Dig/COMI
  * SMUSH code optimised, frame dropping added for slower machines
  * Code cleanups
* Tue Dec 10 2002 mmj@suse.de
- Update to 0.3.0b
* Tue Dec  3 2002 mmj@suse.de
- Use BuildRoot:
* Sat May 18 2002 mmj@suse.de
- Update to 0.2.0
* Wed Apr 17 2002 uli@suse.de
- build and link with g++
* Wed Jan 23 2002 uli@suse.de
- initial package
